### empirical data 

# set working directory
dir <- "/home/jgb/projects/aac"
setwd(dir)

# load some funcitons into memory
source("code/r/community_change_functions.r")
source("code/r/process_empirical_aac.r")
source("code/r/make_naac_vector.r")
source("code/r/perform_simulation.r")

# read in data
aac_data <- read.table("data/empirical.csv", row.names=1, header=FALSE, sep=",", )

# get acc vector
dataset <- "c3"
acc_data <- extract_acc_vector(acc_data,3) 

#########################
### simulation parameters

# initial community size
N = length(acc_data)

# size of species pool
P = 73

# number of time steps (5 My, steps of 1 Ky)
t_max = 5E3

# rate of extinction from community
pex <- 0.003
# rate of immigration to community
pim <- pex * N / (P - N) 


set.seed(67234456)
tr <- perform_simulation(P, N, 0.0092, 0.0092 * N / (P - N) , t_max)
trd <- perform_simulation(P, N, pex, pim, t_max, disturbance_time=100, pex_dist=0.70)
tr_nacc_vec <- make_naac_vector(tr, t_max)
trd_nacc_vec <- make_naac_vector(trd, t_max)

# calculate empirical naac vectors
# with simulaiton t_max
data_nacc_vec <- make_naac_vector(acc_data, t_max)

# make a quick plot, check all is working
sum(abs(tr_nacc_vec - data_nacc_vec))
plot(tr_nacc_vec,xlim=c(3000,5000))
points(data_nacc_vec,col="blue")


png(file=paste("figures/FigS5.png", sep=""), units='in', res=320, height=5, width=5)
plot(data_nacc_vec,xlim=c(3000,5000), xlab="time step", ylab="arrivals (normalized)", cex=1, col="blue")
points(tr_nacc_vec,col="gray", cex=0.5)
points(trd_nacc_vec,col="black", cex=0.5)
dev.off()

