disturbance <- function(pex_dist, v) {

     svec = v$svec
     tvec = v$tvec

     rvec <- runif(length(svec))
     iext <- which(pex_dist > rvec)

     if (length(iext > 0)) {
        svec[ iext ] <- 0
        tvec[ iext ] <- 0
        return(list(svec=svec, tvec=tvec))
     }

     else {
        return(v)
     }
}


# impose extinction and immigration 
# with strict replacement (zero order)

strict_replacement <- function( psr, v ) {

     svec = v$svec
     tvec = v$tvec

     if ( psr > runif(1) ) {
        iext <- sample ( which(svec == 1))[1]
        svec[ iext ] <- 0
        tvec[ iext ] <- 0

        idis <- sample ( which(svec == 0))[1]
        svec[ idis ] <- 1
        tvec[ idis ] <- i

        return(list(svec=svec, tvec=tvec))

      } else {
        return(v)
      }


}


# impose extinction and immigration 
# at constant rates (zero order)
constant_rates <- function( pex, pim, v ) {

     svec = v$svec
     tvec = v$tvec

     if ( pex > runif(1) ) {
        iext <- sample ( which(svec == 1))[1]
        svec[ iext ] <- 0
        tvec[ iext ] <- 0
     }

     if ( pim > runif(1) ) {
        idis <- sample ( which(svec == 0))[1]
        svec[ idis ] <- 1
        tvec[ idis ] <- i
     }

     return(list(svec=svec, tvec=tvec))
}



species_specific_constant_rates <- function( pex, pim, v, i) {

     
     svec = v$svec
     tvec = v$tvec

     rvec_ex <- runif(length(svec))
     rvec_ex[ svec == 0 ] <- 10

     iext <- which(pex > rvec_ex)

     if (length(iext > 0)) {
        svec[ iext ] <- 0
        tvec[ iext ] <- 0
     }

     rvec_im <- runif(length(svec))
     rvec_im[ svec == 1 ] <- 10

     iimm <- which(pim > rvec_im)

     if (length(iimm > 0)) {
        svec[ iimm ] <- 1
        tvec[ iimm ] <- i
     }

     return(list(svec=svec, tvec=tvec))


}


species_specific_constant_rate_classes <- function( pex, pim, v, i, classes=1, pex2=NA, pim2=NA, inds=NA) {
     

     c2 <- FALSE

     if (classes == 2 & class(pex2)=="numeric" & class(pim2)=="numeric" & class(inds)=="numeric") {
        c2 <- TRUE
     }

     svec = v$svec
     tvec = v$tvec

     rvec_ex <- runif(length(svec))
     rvec_ex[ svec == 0 ] <- 10

     pexv <- rep(pex, length(svec))
     if (c2) { pexv[1:inds] <- pex2 }


     iext <- which(pexv > rvec_ex)

     if (length(iext > 0)) {
        svec[ iext ] <- 0
        tvec[ iext ] <- 0
     }

     rvec_im <- runif(length(svec))
     rvec_im[ svec == 1 ] <- 10

     pimv <- rep(pim, length(svec))
     if (c2) { pimv[1:inds] <- pim2 }

     iimm <- which(pimv > rvec_im)

     if (length(iimm > 0)) {
        svec[ iimm ] <- 1
        tvec[ iimm ] <- i
     }

     return(list(svec=svec, tvec=tvec))


}




